#include "fftorder.h"

const unsigned char fftorder_16[] = {
0,8,4,12,2,10,14,6,1,9,5,13,15,7,3,11
} ;
